## vim:ts=4:et:nowrap
##
##---------------------------------------------------------------------------##
##
## PySol -- a Python Solitaire game
##
## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##
## Markus F.X.J. Oberhumer
## <markus.oberhumer@jk.uni-linz.ac.at>
## http://wildsau.idv.uni-linz.ac.at/mfx/pysol.html
##
##---------------------------------------------------------------------------##


# imports
import sys, os

# PySol imports
from mfxutil import win32api
from mfxutil import EnvError
from util import PACKAGE, VERSION
from pysoltk import tkname, makeHelpToplevel
from pysoltk import MfxDialog
from pysoltk import tkHTMLViewer


# /***********************************************************************
# //
# ************************************************************************/

def helpAbout(app, timeout=0, sound=1):
    if sound:
        app.audio.playSample("about")
    t = "A Python Solitaire Game Collection\n"
    if app.miscrandom.random() < 0.8:
        t = "A World Domination Project\n"
    d = MfxDialog(app.top, title="About " + PACKAGE, timeout=timeout,
               text=PACKAGE+"\n" + t +
                    "Version " + VERSION +"\n\n" +
                    "Copyright (C) 1998, 1999, 2000\nMarkus F.X.J. Oberhumer\n" +
                    "markus.oberhumer@jk.uni-linz.ac.at\n\n" +
                    PACKAGE+" is free software distributed under the terms\n" +
                    "of the GNU General Public License\n\n" +
                    "For more information about this application visit\n" +
###                    "http://wildsau.idv.uni-linz.ac.at/mfx/pysol.html\n" +
                    "http://pysol.tsx.org",
               image=app.jokers[2],
               strings=("Nice", "Credits..."), default=0,
               separatorwidth=2)
    if d.status == 0 and d.button == 1:
        helpCredits(app, sound=sound)
    return d.status


def helpCredits(app, timeout=0, sound=1):
    if sound:
        app.audio.playSample("credits")
    t = ""
    if tkname == "tk": t = "Tcl/Tk, "
    elif tkname == "gnome": t = "PyGTK, "
    elif tkname == "kde": t = "pyKDE, "
    elif tkname == "wx": t = "wxPython, "
    d = MfxDialog(app.top, title=PACKAGE+" Credits", timeout=timeout,
               text=PACKAGE+" credits go to:\n\n" +
                    "Volker Weidner for getting me into Solitaire\n" +
                    "Guido van Rossum for the initial example program\n" +
                    "T. Kirk for lots of contributed games and cardsets\n" +
                    "Carl Larsson for the background music\n" +
                    "The Gnome AisleRiot team for parts of the documentation\n" +
                    "\n" +
                    "The Python, " + t + "SDL & Linux crews\nfor making this program possible",
               image=app.jokers[3], image_side="right",
               separatorwidth=2)
    return d.status


# /***********************************************************************
# //
# ************************************************************************/

help_html_index = None

def helpHTML(app, document, dir):
    if not document:
        return None
    try:
        doc = app.dataloader.findFile(document, dir)
        global help_html_index
        if help_html_index is None:
            document, dir = "index.html", "html"
            help_html_index = app.dataloader.findFile(document, dir)
    except EnvError:
        d = MfxDialog(app.top, title=PACKAGE + " HTML Problem",
                      text="Cannot find help document\n" + document,
                      bitmap="warning")
        return None
    top = makeHelpToplevel(app.top, title=PACKAGE+" Help")
    top.wm_minsize(400, 200)
    try:
        top.wm_iconbitmap("@" + app.dataloader.findFile("pysol.xbm"))
        top.wm_iconmask("@" + app.dataloader.findFile("pysol.xbm"))
    except: pass
    viewer = tkHTMLViewer(top)
    viewer.app = app
    ##print doc, help_html_index
    viewer.home = help_html_index
    viewer.display(doc)
    return viewer

