## vim:ts=4:et:nowrap
##
##---------------------------------------------------------------------------##
##
## PySol -- a Python Solitaire game
##
## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##
## Markus F.X.J. Oberhumer
## <markus.oberhumer@jk.uni-linz.ac.at>
## http://wildsau.idv.uni-linz.ac.at/mfx/pysol.html
##
##---------------------------------------------------------------------------##


# imports
import os, sys, string, types
import Tkinter, Canvas


# /***********************************************************************
# // patch lib-tk/Tkinter.py
# ************************************************************************/

# fix Python 1.5.2 _tagcommands bug
def Canvas__tag_bind(self, tagOrId, sequence=None, func=None, add=None):
    return self._bind((self._w, "bind", tagOrId), sequence, func, add)


Tkinter.Canvas.tag_bind = Canvas__tag_bind


# /***********************************************************************
# // patch lib-tk/Canvas.py
# ************************************************************************/

# fix inconsistent bbox() return value
def CanvasItem__bbox(self):
    return self.canvas.bbox(self.id)
def Group__bbox(self):
    return self.canvas.bbox(self.id)

# fix missing "add" as distributed in all Python versions
def CanvasItem__bind(self, sequence=None, command=None, add=None):
    return self.canvas.tag_bind(self.id, sequence, command, add)
def Group__bind(self, sequence=None, command=None, add=None):
    return self.canvas.tag_bind(self.id, sequence, command, add)

# fix a bug in unbind as distributed in all Python versions
def CanvasItem__unbind(self, sequence, funcid=None):
    return self.canvas.tag_unbind(self.id, sequence, funcid)
def Group__unbind(self, sequence, funcid=None):
    return self.canvas.tag_unbind(self.id, sequence, funcid)

#
def CanvasItem__tkraise(self, abovethis=None):
    return self.canvas.tag_raise(self.id, abovethis)
def CanvasItem__lower(self, belowthis=None):
    return self.canvas.tag_lower(self.id, belowthis)
def Group__tkraise(self, abovethis=None):
    return self.canvas.tag_raise(self.id, abovethis)
def Group__lower(self, belowthis=None):
    return self.canvas.tag_lower(self.id, belowthis)


# other problems in Canvas.Group:
#   - inconsistent usage of self.id and self.tag
#   - calls the obsolete Tkinter.Canvas._do method


Canvas.CanvasItem.bbox = CanvasItem__bbox
Canvas.Group.bbox = Group__bbox
Canvas.CanvasItem.bind = CanvasItem__bind
Canvas.Group.bind = Group__bind
Canvas.CanvasItem.unbind = CanvasItem__unbind
Canvas.Group.unbind = Group__unbind
Canvas.CanvasItem.tkraise = CanvasItem__tkraise
Canvas.CanvasItem.lower = CanvasItem__lower
Canvas.Group.tkraise = Group__tkraise
Canvas.Group.lower = Group__lower

